==> haskell-fclabels-2.0.3.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fclabels.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fclabels
version: 2.0.3.1
id: fclabels-2.0.3.1-CzfwbCdhZtzAt5mF8eE0Nx
key: fclabels-2.0.3.1-CzfwbCdhZtzAt5mF8eE0Nx
license: BSD3
maintainer: Sebastiaan Visser <code@fvisser.nl>
homepage: https://github.com/sebastiaanvisser/fclabels
synopsis: First class accessor labels implemented as lenses.
description:
    This package provides first class labels that can act as
    bidirectional record fields. The labels can be derived
    automatically using Template Haskell which means you don'\''t have
    to write any boilerplate yourself. The labels are implemented as
    /lenses/ and are fully composable. Lenses can be used to /get/,
    /set/ and /modify/ parts of a data type in a consistent way.
    .
    See "Data.Label" for an introductory explanation or see the
    introductory blog post at
    <http://fvisser.nl/post/2013/okt/1/fclabels-2.0.html>
    .
    * /Total and partial lenses/
    .
    Internally lenses do not used Haskell functions directly, but
    are implemented as categories. Categories allow the lenses to be
    run in custom computational contexts. This approach allows us to
    make partial lenses that point to fields of multi-constructor
    datatypes in an elegant way.
    .
    See "Data.Label.Partial" for the use of partial labels.
    .
    * /Monomorphic and polymorphic lenses/
    .
    We have both polymorphic and monomorphic lenses. Polymorphic
    lenses allow updates that change the type. The types of
    polymorphic lenses are slightly more verbose than their
    monomorphic counterparts, but their usage is similar. Because
    monomorphic lenses are built by restricting the types of
    polymorphic lenses they are essentially the same and can be
    freely composed with eachother.
    .
    See "Data.Label.Mono" and "Data.Label.Poly" for the difference
    between polymorphic and monomorphic lenses.
    .
    * /Using fclabels/
    .
    To simplify working with labels we supply both a set of labels
    for Haskell'\''s base types, like lists, tuples, Maybe and Either,
    and we supply a set of combinators for working with labels for
    values in the Reader and State monad.
    .
    See "Data.Label.Base" and "Data.Label.Monadic" for more
    information.
    .
    * /Changelog from 2.0.2.4 to 2.0.3/
    .
    >   - Allow HUnit 1.4.*.
    >   - Fix test suite on GHC 7.4.
category: Data, Lenses
author: Sebastiaan Visser, Erik Hesselink, Chris Eidhof, Sjoerd Visscher
        with lots of help and feedback from others.
exposed: True
exposed-modules:
    Data.Label Data.Label.Base Data.Label.Derive Data.Label.Failing
    Data.Label.Monadic Data.Label.Mono Data.Label.Partial
    Data.Label.Point Data.Label.Poly Data.Label.Total
abi: 881a0eaa9a160ad4fa66009d4a9dcf3d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/fclabels-2.0.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/fclabels-2.0.3.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/fclabels-2.0.3.1
hs-libraries: HSfclabels-2.0.3.1-CzfwbCdhZtzAt5mF8eE0Nx
depends:
    base-4.9.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    template-haskell-2.11.0.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-fclabels/html/fclabels.haddock
haddock-html: /usr/share/doc/haskell-fclabels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fclabels-2.0.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fclabels.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fclabels
version: 2.0.3
id: fclabels-2.0.3-1gej0iPmuXY7XeHHsUuCmq
key: fclabels-2.0.3-1gej0iPmuXY7XeHHsUuCmq
license: BSD3
maintainer: Sebastiaan Visser <code@fvisser.nl>
homepage: https://github.com/sebastiaanvisser/fclabels
synopsis: First class accessor labels implemented as lenses.
description:
    This package provides first class labels that can act as
    bidirectional record fields. The labels can be derived
    automatically using Template Haskell which means you don'\''t have
    to write any boilerplate yourself. The labels are implemented as
    /lenses/ and are fully composable. Lenses can be used to /get/,
    /set/ and /modify/ parts of a data type in a consistent way.
    .
    See "Data.Label" for an introductory explanation or see the
    introductory blog post at
    <http://fvisser.nl/post/2013/okt/1/fclabels-2.0.html>
    .
    * /Total and partial lenses/
    .
    Internally lenses do not used Haskell functions directly, but
    are implemented as categories. Categories allow the lenses to be
    run in custom computational contexts. This approach allows us to
    make partial lenses that point to fields of multi-constructor
    datatypes in an elegant way.
    .
    See "Data.Label.Partial" for the use of partial labels.
    .
    * /Monomorphic and polymorphic lenses/
    .
    We have both polymorphic and monomorphic lenses. Polymorphic
    lenses allow updates that change the type. The types of
    polymorphic lenses are slightly more verbose than their
    monomorphic counterparts, but their usage is similar. Because
    monomorphic lenses are built by restricting the types of
    polymorphic lenses they are essentially the same and can be
    freely composed with eachother.
    .
    See "Data.Label.Mono" and "Data.Label.Poly" for the difference
    between polymorphic and monomorphic lenses.
    .
    * /Using fclabels/
    .
    To simplify working with labels we supply both a set of labels
    for Haskell'\''s base types, like lists, tuples, Maybe and Either,
    and we supply a set of combinators for working with labels for
    values in the Reader and State monad.
    .
    See "Data.Label.Base" and "Data.Label.Monadic" for more
    information.
    .
    * /Changelog from 2.0.2.4 to 2.0.3/
    .
    >   - Support GHC 8.
category: Data, Lenses
author: Sebastiaan Visser, Erik Hesselink, Chris Eidhof, Sjoerd Visscher
        with lots of help and feedback from others.
exposed: True
exposed-modules:
    Data.Label Data.Label.Base Data.Label.Derive Data.Label.Failing
    Data.Label.Monadic Data.Label.Mono Data.Label.Partial
    Data.Label.Point Data.Label.Poly Data.Label.Total
abi: 6fb368ec7e6aa28f1ab7f4516e5000e3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/fclabels-2.0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/fclabels-2.0.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/fclabels-2.0.3
hs-libraries: HSfclabels-2.0.3-1gej0iPmuXY7XeHHsUuCmq
depends:
    base-4.9.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    template-haskell-2.11.0.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-fclabels/html/fclabels.haddock
haddock-html: /usr/share/doc/haskell-fclabels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
